
<br>

### `String.normalize_spaces()`

This method will replace all special space characters with normal spaces.<br>
**Params:**
- <code>code: *str*</code> the string to normalize
- <code>tab_spaces: *int*</code> the amount of spaces to replace tab characters with (*default* `4`)

**Returns:** the normalized string

<br>
